#!/usr/local/bin/python
"""
Why implement a python based entrypoint?
 - subprocess waits for process completion and thus eliminates the need for a wait-loop
 - enables the use of smaller docker images omitting the shell requirement
"""

import os.path
import subprocess
import sys


def run_django_manage(django_cmd, django_cmd_parameter):
    """
    Runs given django command with given parameter.

    :param django_cmd: command to execute with manage.py
    :param django_cmd_parameter: parameter for the fore mentioned command
    :return: nothing
    """
    python_interpreter: str = "/usr/local/bin/python"
    django_manage: str = "manage.py"

    if not os.path.isfile(python_interpreter):
        sys.exit("Interpreter " + python_interpreter + " not found.")

    if not os.path.isfile(django_manage):
        sys.exit(django_manage + " file is missing.")

    try:
        subprocess.check_call([python_interpreter,
                               django_manage,
                               django_cmd,
                               django_cmd_parameter], shell=False)
    except FileNotFoundError as error:
        sys.exit(error.strerror)
    except subprocess.CalledProcessError as error:
        print(django_cmd + " exited with non zero exit code.")
        sys.exit(error.returncode)


print("Migrate the database at startup.")
run_django_manage("migrate", "--fake-initial")
print("Migration done. Starting Django")
run_django_manage("runserver", "0.0.0.0:8000")
