"""
Django settings for one_api project.

Generated by 'django-admin startproject' using Django 3.1.7.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

import logging
from pathlib import Path
# use PyMySQL to get rid of the c extension in mysqlclient
# https://adamj.eu/tech/2020/02/04/how-to-use-pymysql-with-django/
import pymysql

logger = logging.getLogger('one_api.prod_settings')

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
secret_file = Path('./secret_key.txt')
try:
    secret_abs_path = secret_file.resolve(strict=True)
except FileNotFoundError:
    print('Secret File not Found')
else:
    # exists
    with secret_abs_path.open() as f:
        SECRET_KEY = f.read().strip()


# SECURITY WARNING: don't run with debug turned on in production!
# TODO: Listen to this warning
DEBUG = True

ALLOWED_HOSTS = ['oneup-02.cs.uni-potsdam.de', '.localhost', '[::1]', '127.0.0.1']


# Application definition

INSTALLED_APPS = [
    'articles.apps.ArticlesConfig',
    'veranstaltung.apps.VeranstaltungsConfig',
    'rest_framework',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'corsheaders',
    'drf_yasg',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'corsheaders.middleware.CorsMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'one_api.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'one_api.wsgi.application'
CORS_ALLOWED_ORIGINS = [
    "http://localhost:4200",
    "http://127.0.0.1:4200",
]

# Database
# https://docs.djangoproject.com/en/3.1/ref/settings/#databases


def read_password_from_file(filename):
    db_password_file = Path('./'+filename)
    try:
        db_password_file.resolve(strict=True)
    except FileNotFoundError:
        logger.error('could not read db password from file' + str(db_password_file))
        return ''
    else:
        # exists
        with db_password_file.open() as file:
            return file.read().strip()


# DOCKER
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': 'mise_pr',
        'USER': 'misepr',
        'PASSWORD': read_password_from_file('db_password.txt'),
        'HOST': 'misepr-db',
        'PORT': '3306'
    }
}

# Fake PyMySQL's version and install as MySQLdb
# https://adamj.eu/tech/2020/02/04/how-to-use-pymysql-with-django/
pymysql.version_info = (1, 4, 2, "final", 0)
pymysql.install_as_MySQLdb()

# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.1/howto/static-files/

STATIC_URL = '/restapi/static/'

# get local settings
try:
    from one_api.settings_local import *
except ImportError:
    pass
