from django.db import models
# Create your models here.


class Author(models.Model):
    """Model of a single author"""
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    mailAddress = models.CharField(max_length=255, unique=True)

    def __str__(self):
        return self.name

    class Meta:
        """Definition of MySQL Table"""
        db_table = "author"


class Event(models.Model):
    """Model of a single event, which is connected to a author and valued indicators"""
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    start_time = models.DateTimeField('start_time')
    last_updated = models.DateTimeField('last_updated')
    author = models.ManyToManyField(Author)
    # valued_indicators = models.ManyToOneRel(ValuedIndicator, through='EventValuedIndicator')

    def __str__(self):
        return self.name

    class Meta:
        """Definition of MySQL Table"""
        db_table = "event"


class Feedback(models.Model):
    """Model of a single feedback, which is connected to valued indicators"""
    id = models.AutoField(primary_key=True)
    submit_time = models.DateTimeField('submit_time')
    event = models.OneToOneField(Event, on_delete=models.CASCADE)

    class Meta:
        """Definition of MySQL Table"""
        db_table = "feedback"


class Indicator(models.Model):
    """Model of a single indicator"""
    id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=255)
    description = models.CharField(max_length=255)
    is_public = models.BooleanField()

    def __str__(self):
        return self.name

    class Meta:
        """Definition of MySQL Table"""
        db_table = "indicator"


class ValuedIndicator(models.Model):
    """Model of a single valued indicator"""
    id = models.AutoField(primary_key=True)
    proposed = models.IntegerField(default=0)
    actual = models.IntegerField(default=0)
    indicators = models.ManyToManyField(Indicator)
    feedback = models.ForeignKey(Feedback, on_delete=models.CASCADE)

    class Meta:
        """Definition of MySQL Table"""
        db_table = "valued_indicator"
